@@ -64,7 +64,7 @@ use namespace::autoclean;
 
 # PODNAME: Dist::Zilla::Plugin::Manifest::Write
 # ABSTRACT: Have annotated distribution manifest
-our $VERSION = 'v0.8.1_01'; # TRIAL VERSION
+our $VERSION = 'v0.8.1_02'; # TRIAL VERSION
 
 with 'Dist::Zilla::Role::FileGatherer';
 with 'Dist::Zilla::Role::BeforeBuild';
@@ -261,7 +261,7 @@ has metainfo_providers => (
 
 sub _build_metainfo_providers {
     my ( $self ) = @_;
-    my @list = ( qw{ MetaYAML MetaJSON Manifest Manifest::Write }, __plugin_moniker( $self ) );
+    my @list = ( qw{ MetaYAML MetaJSON Manifest Manifest::Write }, $self->plugin_name );
     if ( $self->strict >= 0 ) {
         @list = grep( { $self->_is_injector( $_ ) } @list );
     };
@@ -860,7 +860,7 @@ Dist::Zilla::Plugin::Manifest::Write - Have annotated distribution manifest
 
 =head1 VERSION
 
-Version v0.8.1_01, released on 2015-10-01 22:06 UTC.
+Version v0.8.1_02, released on 2015-10-02 13:28 UTC.
 This is a B<trial release>.
 
 =head1 WHAT?
